@@ -4,6 +4,7 @@ import svg.path
 import xml.etree.ElementTree as ET
 import os
 import copy
+import warnings
 
 '''
 Compress svg figure through a variety of methods
@@ -25,7 +26,15 @@ class Compress:
         tag_prefix = self._get_tag_prefix()
         self.path_nodes = self.root.findall('.//%spath' %(tag_prefix))
         self.path_parents = self.root.findall('.//%spath/..' %(tag_prefix))
-        self.paths = [svg.path.parse_path(p.attrib['d']) for p in self.path_nodes]
+        self.paths = list()
+#         for p in self.path_nodes:
+#             try:
+#                 self.paths.append(svg.path.parse_path(p.attrib['d']))
+#             except KeyError, e:
+#                 # Items such as clipping paths have no coordinates
+#                 warnings.warn('Detected path with no coordinates: e.message')
+#                 pass
+        self.paths = [svg.path.parse_path(p.attrib.get('d', 'M 0,0 z')) for p in self.path_nodes]
         
     def linearize_paths(self, curve_fidelity = 10):
         '''
@@ -171,7 +180,8 @@ class Compress:
         n_deleted = 0 # Reporting variable for number of polygons unified
         if group_by_color:
             nullstyle = 'fill:#zzzzzz;fill-opacity:-1' # Some paths (e.g. clipping paths) don't have styles
-            self.colors = numpy.array([vector_utils.parse_style(p.attrib.get('style', nullstyle))['fill'] for p in self.path_nodes])
+            styles = [vector_utils.parse_style(p.attrib.get('style', nullstyle)) for p in self.path_nodes]
+            self.colors = numpy.array([style.get('fill', '#zzzzzz') for style in styles])
             color_str = numpy.unique(self.colors)
             color_groupings = [numpy.where(self.colors == c)[0] for c in color_str]
         for color in color_groupings:
@@ -286,13 +296,14 @@ def test(filename, thresholds = (5, 2), epsilon = 0.5, curve_fidelity = 10,
     ## Compress by unification:
     outputfile = ''.join((filestr, '_merged.', extension))
     compress_by_method(filename, 'merge', curve_fidelity, outputfile, pre_select = True, 
-                       selection_tuple = (criterias[0], thresholds[0]), epsilon = epsilon)
+                       selection_tuple = (criterias[0], thresholds[0]), epsilon = epsilon,
+                       group_by_color = False)
 
     ## Compress by convex hull:
     outputfile = ''.join((filestr, '_hull.', extension))
     compress_by_method(filename, 'merge', curve_fidelity, outputfile, pre_select = True, 
                        selection_tuple = (criterias[0], thresholds[0]), epsilon = epsilon, 
-                       bufferDistance = buffer_distance, operation_key = 'hull')
+                       bufferDistance = buffer_distance, operation_key = 'hull', group_by_color = False)
     
     ## Lastly, see if uncompressed file is same as original:
     # TODO: Find out why wierdly, it never is.
@@ -305,4 +316,6 @@ if __name__ == '__main__':
     # Demonstrate all functions with pre-prepared test vector
     test(filename = 'test/test_vector.svg', thresholds = (300, 150), epsilon = 5, buffer_distance = 10)
     # Demonstrate all functions with sample map
-    test(filename = 'test/map_test.svg', thresholds = (6, 3), epsilon = 30, buffer_distance = 50)
+    test(filename = 'test/map_test.svg', thresholds = (6, 3), epsilon = 30, buffer_distance = 20)
+    # Demonstrate with a plot constructed in matplotlib
+    test(filename = 'test/matplotlib_test.svg', thresholds = (1000, 100), epsilon = 2, buffer_distance = 200)
